import * as stream from 'stream';
import { TextDecoder } from 'util';

export default function streamToString(inputStream: stream.Readable, encoding: string = 'utf-8'): Promise<string> {
  const decoder = new TextDecoder(encoding); //utf-8 or utf-16le

  return new Promise((resolve, reject) => {
    const stringParts: string[] = [];

    //Convert chunks to string
    inputStream.on('data', (chunk: Buffer) => {
      stringParts.push(decoder.decode(chunk, { stream: true }));
    });

    //Output final string
    inputStream.on('end', () => {
      stringParts.push(decoder.decode());
      resolve(stringParts.join(''));
    });

    //Exit on error
    inputStream.on('error', (error) => {
      reject(error);
    });
  });
}
